==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/realm/HotRodRealmEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.realm;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodRealmEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity, org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.RealmModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.RealmModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity, org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity.HotRodRealmEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-21.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/realm/HotRodRealmEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.realm;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodRealmEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity, org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.RealmModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.RealmModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity, org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.realm.HotRodRealmEntity.HotRodRealmEntitySchema.INSTANCE;
    }
}
